@@ -1,3 +1,30 @@
+/*****
+ *       Xnee's Not an Event Emulator                                
+ *                                                                   
+ * Xnee enables recording and replaying of X protocol data           
+ *                                                                   
+ *   Copyright (C) 2006, 2007, 2010
+ *                        Henrik Sandklef 
+ *                                                                   
+ * This program is free software; you can redistribute it and/or     
+ * modify it under the terms of the GNU General Public License       
+ * as published by the Free Software Foundation; either version 3    
+ * of the License, or any later version.                             
+ *                                                                   
+ *                                                                   
+ * This program is distributed in the hope that it will be useful,   
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of    
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
+ * GNU General Public License for more details.                      
+ *                                                                   
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software       
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
+ ****/
+
+
+
 #include <stdio.h>
 
 #include "libxnee/xnee.h"
@@ -247,6 +274,7 @@ int test_xnee_data()
   }
   
   printf ("\n");
+  return XNEE_OK;
 }
 
 
